@@ -4,69 +4,84 @@
 <context>
     <name>AdvancedSettings</name>
     <message>
-        <location filename="../advancedsettings.ui" line="17"/>
+        <location filename="../advancedsettings.ui" line="67"/>
         <source>Sizes</source>
         <translation>Größen</translation>
     </message>
     <message>
-        <location filename="../advancedsettings.ui" line="25"/>
+        <location filename="../advancedsettings.ui" line="75"/>
         <source>Width:</source>
         <translation>Breite:</translation>
     </message>
     <message>
-        <location filename="../advancedsettings.ui" line="32"/>
-        <location filename="../advancedsettings.ui" line="56"/>
+        <location filename="../advancedsettings.ui" line="82"/>
+        <location filename="../advancedsettings.ui" line="106"/>
         <source> px</source>
         <translation> px</translation>
     </message>
     <message>
-        <location filename="../advancedsettings.ui" line="49"/>
+        <location filename="../advancedsettings.ui" line="99"/>
         <source>Spacing:</source>
         <translation>Abstand:</translation>
     </message>
     <message>
-        <location filename="../advancedsettings.ui" line="68"/>
+        <location filename="../advancedsettings.ui" line="118"/>
         <source>Duration</source>
         <translation>Dauer</translation>
     </message>
     <message>
-        <location filename="../advancedsettings.ui" line="80"/>
+        <location filename="../advancedsettings.ui" line="130"/>
         <source>Some notifications set their own on-screen duration.</source>
         <translation>Einige Benachrichtigungen setzen ihre eigene Anzeigedauer.</translation>
     </message>
     <message>
-        <location filename="../advancedsettings.ui" line="92"/>
+        <location filename="../advancedsettings.ui" line="142"/>
         <source>Default duration:</source>
         <translation>Standarddauer:</translation>
     </message>
     <message>
-        <location filename="../advancedsettings.ui" line="99"/>
+        <location filename="../advancedsettings.ui" line="149"/>
         <source> sec</source>
         <translation> Sek</translation>
     </message>
     <message>
-        <location filename="../advancedsettings.ui" line="127"/>
+        <location filename="../advancedsettings.ui" line="177"/>
+        <source>Screen</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../advancedsettings.ui" line="183"/>
+        <source>When unchecked the notification will always show on primary screen</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../advancedsettings.ui" line="186"/>
+        <source>Show notifications on screen with the mouse</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../advancedsettings.ui" line="17"/>
         <source>Unattended Notifications</source>
         <translation>Unbeaufsichtigte Benachrichtigungen</translation>
     </message>
     <message>
-        <location filename="../advancedsettings.ui" line="135"/>
+        <location filename="../advancedsettings.ui" line="25"/>
         <source>How many to save:</source>
         <translation>Wie viele sollen gespeichert werden:</translation>
     </message>
     <message>
-        <location filename="../advancedsettings.ui" line="149"/>
-        <location filename="../advancedsettings.ui" line="159"/>
+        <location filename="../advancedsettings.ui" line="39"/>
+        <location filename="../advancedsettings.ui" line="49"/>
         <source>Application name is on the top of notification.</source>
         <translation>Anwendungsname steht oben in der Benachrichtigung.</translation>
     </message>
     <message>
-        <location filename="../advancedsettings.ui" line="152"/>
+        <location filename="../advancedsettings.ui" line="42"/>
         <source>Ignore these applications:</source>
         <translation>Diese Anwendungen ignorieren:</translation>
     </message>
     <message>
-        <location filename="../advancedsettings.ui" line="162"/>
+        <location filename="../advancedsettings.ui" line="52"/>
         <source>app1,app2,app3</source>
         <translation>App1,App2,App3</translation>
     </message>
@@ -84,26 +99,32 @@
         <translation>Position auf dem Bildschirm</translation>
     </message>
     <message>
-        <location filename="../basicsettings.cpp" line="56"/>
+        <location filename="../basicsettings.cpp" line="61"/>
+        <source>&lt;b&gt;Warning:&lt;/b&gt; notifications daemon is slow to respond.
+Keep trying to connect…</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../basicsettings.cpp" line="70"/>
         <source>&lt;b&gt;Warning:&lt;/b&gt; No notifications daemon is running.
 A fallback will be used.</source>
         <translation>&lt;b&gt;Warnung:&lt;/b&gt; Es läuft kein Benachrichtigungsdaemon.
 Ein Ersatz wird verwendet.</translation>
     </message>
     <message>
-        <location filename="../basicsettings.cpp" line="59"/>
+        <location filename="../basicsettings.cpp" line="73"/>
         <source>&lt;b&gt;Warning:&lt;/b&gt; A third-party notifications daemon (%1) is running.
 These settings won&apos;t have any effect on it!</source>
         <translation>&lt;b&gt;Warnung:&lt;/b&gt; Ein Benachrichtigungsdaemon (%1) von Drittanbietern läuft.
 Diese Einstellungen wirken sich auf ihn nicht aus!</translation>
     </message>
     <message>
-        <location filename="../basicsettings.cpp" line="112"/>
+        <location filename="../basicsettings.cpp" line="131"/>
         <source>Notification demo </source>
         <translation>Testbenachrichtigung </translation>
     </message>
     <message>
-        <location filename="../basicsettings.cpp" line="113"/>
+        <location filename="../basicsettings.cpp" line="132"/>
         <source>This is a test notification.
  All notifications will now appear here on LXQt.</source>
         <translation>Dies ist eine Testbenachrichtigung.
