@@ -4,69 +4,84 @@
 <context>
     <name>AdvancedSettings</name>
     <message>
-        <location filename="../advancedsettings.ui" line="17"/>
+        <location filename="../advancedsettings.ui" line="67"/>
         <source>Sizes</source>
         <translation>Groottes</translation>
     </message>
     <message>
-        <location filename="../advancedsettings.ui" line="25"/>
+        <location filename="../advancedsettings.ui" line="75"/>
         <source>Width:</source>
         <translation>Breedte:</translation>
     </message>
     <message>
-        <location filename="../advancedsettings.ui" line="32"/>
-        <location filename="../advancedsettings.ui" line="56"/>
+        <location filename="../advancedsettings.ui" line="82"/>
+        <location filename="../advancedsettings.ui" line="106"/>
         <source> px</source>
         <translation> px</translation>
     </message>
     <message>
-        <location filename="../advancedsettings.ui" line="49"/>
+        <location filename="../advancedsettings.ui" line="99"/>
         <source>Spacing:</source>
         <translation>Afstand:</translation>
     </message>
     <message>
-        <location filename="../advancedsettings.ui" line="68"/>
+        <location filename="../advancedsettings.ui" line="118"/>
         <source>Duration</source>
         <translation>Duur</translation>
     </message>
     <message>
-        <location filename="../advancedsettings.ui" line="80"/>
+        <location filename="../advancedsettings.ui" line="130"/>
         <source>Some notifications set their own on-screen duration.</source>
         <translation>Enkele kennisgevingen gebruiken hun eigen schermduur.</translation>
     </message>
     <message>
-        <location filename="../advancedsettings.ui" line="92"/>
+        <location filename="../advancedsettings.ui" line="142"/>
         <source>Default duration:</source>
         <translation>Standaardduur:</translation>
     </message>
     <message>
-        <location filename="../advancedsettings.ui" line="99"/>
+        <location filename="../advancedsettings.ui" line="149"/>
         <source> sec</source>
         <translation> sec</translation>
     </message>
     <message>
-        <location filename="../advancedsettings.ui" line="127"/>
+        <location filename="../advancedsettings.ui" line="177"/>
+        <source>Screen</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../advancedsettings.ui" line="183"/>
+        <source>When unchecked the notification will always show on primary screen</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../advancedsettings.ui" line="186"/>
+        <source>Show notifications on screen with the mouse</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../advancedsettings.ui" line="17"/>
         <source>Unattended Notifications</source>
         <translation>Niet afgehandelde notificaties</translation>
     </message>
     <message>
-        <location filename="../advancedsettings.ui" line="135"/>
+        <location filename="../advancedsettings.ui" line="25"/>
         <source>How many to save:</source>
         <translation>Aantal op te slaan:</translation>
     </message>
     <message>
-        <location filename="../advancedsettings.ui" line="149"/>
-        <location filename="../advancedsettings.ui" line="159"/>
+        <location filename="../advancedsettings.ui" line="39"/>
+        <location filename="../advancedsettings.ui" line="49"/>
         <source>Application name is on the top of notification.</source>
         <translation>Applicatienaam staat bovenaan de notificatie.</translation>
     </message>
     <message>
-        <location filename="../advancedsettings.ui" line="152"/>
+        <location filename="../advancedsettings.ui" line="42"/>
         <source>Ignore these applications:</source>
         <translation>Negeer deze applicaties:</translation>
     </message>
     <message>
-        <location filename="../advancedsettings.ui" line="162"/>
+        <location filename="../advancedsettings.ui" line="52"/>
         <source>app1,app2,app3</source>
         <translation>app1,app2,app3</translation>
     </message>
@@ -84,26 +99,32 @@
         <translation>Positie op scherm</translation>
     </message>
     <message>
-        <location filename="../basicsettings.cpp" line="56"/>
+        <location filename="../basicsettings.cpp" line="61"/>
+        <source>&lt;b&gt;Warning:&lt;/b&gt; notifications daemon is slow to respond.
+Keep trying to connect…</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../basicsettings.cpp" line="70"/>
         <source>&lt;b&gt;Warning:&lt;/b&gt; No notifications daemon is running.
 A fallback will be used.</source>
         <translation>&lt;b&gt;Waarschuwing:&lt;/b&gt; er draait geen achtergronddienst voor notificaties.
 Er zal een vervangende dienst worden gebruikt.</translation>
     </message>
     <message>
-        <location filename="../basicsettings.cpp" line="59"/>
+        <location filename="../basicsettings.cpp" line="73"/>
         <source>&lt;b&gt;Warning:&lt;/b&gt; A third-party notifications daemon (%1) is running.
 These settings won&apos;t have any effect on it!</source>
         <translation>&lt;b&gt;Waarschuwing:&lt;/b&gt; er draait al een andere achtergrondddienst voor notificaties (%1).
 Deze instellingen zullen daarop geen invloed hebben!</translation>
     </message>
     <message>
-        <location filename="../basicsettings.cpp" line="112"/>
+        <location filename="../basicsettings.cpp" line="131"/>
         <source>Notification demo </source>
         <translation>Voorbeeldnotificatie </translation>
     </message>
     <message>
-        <location filename="../basicsettings.cpp" line="113"/>
+        <location filename="../basicsettings.cpp" line="132"/>
         <source>This is a test notification.
  All notifications will now appear here on LXQt.</source>
         <translation>Dit is een voorbeeldnotificatie.
