@@ -11,29 +11,28 @@
     <message>
         <location filename="../notificationwidgets.cpp" line="122"/>
         <source>OK</source>
-        <translation></translation>
+        <translation>OK</translation>
     </message>
 </context>
 <context>
     <name>Notifyd</name>
     <message>
-        <location filename="../notifyd.cpp" line="226"/>
+        <location filename="../notifyd.cpp" line="227"/>
         <source>Clear All</source>
-        <translation>Tisztítás</translation>
+        <translation>Törlés</translation>
     </message>
     <message>
-        <location filename="../notifyd.cpp" line="234"/>
+        <location filename="../notifyd.cpp" line="235"/>
         <source>Options</source>
         <translation>Beállítások</translation>
     </message>
     <message numerus="yes">
-        <location filename="../notifyd.cpp" line="241"/>
-        <location filename="../notifyd.cpp" line="299"/>
-        <location filename="../notifyd.cpp" line="319"/>
+        <location filename="../notifyd.cpp" line="242"/>
+        <location filename="../notifyd.cpp" line="300"/>
+        <location filename="../notifyd.cpp" line="320"/>
         <source>%n Unattended Notification(s)</source>
         <translation>
             <numerusform>%n olvasatlan értesítés</numerusform>
-            <numerusform>%n olvasatlan értesítés</numerusform>
         </translation>
     </message>
 </context>
